import * as d3 from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/sridhar2606/971180e0afc8ee79194592bbbccd8986/raw/25a71dd4b3e034b20ff5a9cf97c7c9b47637ff3e/gistfile1.txt';
const width = 800;
const height = 500;
const margin = {
  top: 20,
  right: 20,
  bottom: 50,
  left: 100,
};

const svg = d3
  .select('#root')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const render = (data) => {
  const x = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d['2021'])])
    .nice()
    .range([margin.left, width - margin.right]);

  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d['2019'])])
    .nice()
    .range([height - margin.bottom, margin.top]);

  svg.selectAll('g').remove();

  const xAxis = (g) =>
    g
      .attr(
        'transform',
        `translate(0,${height - margin.bottom})`,
      )
      .call(
        d3
          .axisBottom(x)
          .ticks(width / 80)
          .tickSizeOuter(0),
      )
      .call((g) => g.selectAll('.domain').remove())
      .call((g) =>
        g
          .append('text')
          .attr('x', width / 2)
          .attr('y', margin.bottom - 10)
          .attr('fill', 'currentColor')
          .attr('text-anchor', 'middle')
          .text('2021 Visitors')
          .attr('class', 'axis-label'),
      );

  const yAxis = (g) =>
    g
      .attr('transform', `translate(${margin.left},0)`)
      .call(d3.axisLeft(y).ticks(null, 's'))
      .call((g) => g.selectAll('.domain').remove())
      .call((g) =>
        g
          .append('text')
          .attr('x', -margin.left)
          .attr('y', 10)
          .attr('fill', 'currentColor')
          .attr('text-anchor', 'start')
          .text('2019 Visitors')
          .attr('class', 'axis-label'),
      );

  svg
    .append('g')
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('class', 'dot')
    .attr('cx', (d) => x(d['2021']))
    .attr('cy', (d) => y(d['2019']))
    .attr('r', 5);

  svg.append('g').call(xAxis);

  svg.append('g').call(yAxis);
};

d3.csv(csvUrl, d3.autoType).then((data) => {
  render(data);
});
